@@ -262,7 +262,7 @@ enum {
   SPVM_OPCODE_C_ID_GET_CONSTANT_LONG,
   SPVM_OPCODE_C_ID_GET_CONSTANT_FLOAT,
   SPVM_OPCODE_C_ID_GET_CONSTANT_DOUBLE,
-  SPVM_OPCODE_C_ID_CASE,
+  SPVM_OPCODE_C_ID_ISA_INTERFACE,
   SPVM_OPCODE_C_ID_IF_CROAK_CATCH,
   SPVM_OPCODE_C_ID_IF_CROAK_RETURN,
   SPVM_OPCODE_C_ID_SET_CROAK_FLAG_TRUE,
@@ -285,15 +285,15 @@ enum {
   SPVM_OPCODE_C_ID_PUSH_ARG_DOUBLE,
   SPVM_OPCODE_C_ID_PUSH_ARG_OBJECT,
   SPVM_OPCODE_C_ID_PUSH_ARG_UNDEF,
-  SPVM_OPCODE_C_ID_CAST,
+  SPVM_OPCODE_C_ID_CHECK_OBJECT_TYPE,
   SPVM_OPCODE_C_ID_STRING_EQ,
   SPVM_OPCODE_C_ID_STRING_NE,
   SPVM_OPCODE_C_ID_STRING_GT,
   SPVM_OPCODE_C_ID_STRING_GE,
   SPVM_OPCODE_C_ID_STRING_LT,
   SPVM_OPCODE_C_ID_STRING_LE,
-  SPVM_OPCODE_C_ID_ISA,
-  SPVM_OPCODE_C_ID_END_SUB,
+  SPVM_OPCODE_C_ID_ISA_OBJECT,
+  SPVM_OPCODE_C_ID_CHECK_INTERFACE_TYPE,
   SPVM_OPCODE_C_ID_VALUE_T_ARRAY_FIELD_FETCH_BYTE,
   SPVM_OPCODE_C_ID_VALUE_T_ARRAY_FIELD_FETCH_SHORT,
   SPVM_OPCODE_C_ID_VALUE_T_ARRAY_FIELD_FETCH_INT,
@@ -383,6 +383,7 @@ enum {
   SPVM_OPCODE_C_ID_GET_EXCEPTION_VAR,
   SPVM_OPCODE_C_ID_SET_EXCEPTION_VAR,
   SPVM_OPCODE_C_ID_SET_EXCEPTION_VAR_UNDEF,
+  SPVM_OPCODE_C_ID_END_SUB,
 };
 
 enum {
